#[repr(u8)]pub enum DftXadr {
Show 16 variants
ZZ252 = 0,
ZZ253 = 1,
ZZ254 = 2,
ZZ255 = 3,
ZZ256 = 4,
ZZ257 = 5,
ZZ258 = 6,
ZZ259 = 7,
ZZ260 = 8,
ZZ261 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Variants
ZZ252 = 0
XADR fixed, no change at all
ZZ253 = 1
XADR increased by 1 after row. For READ operation, XADR increases by 1 after reading the last word of row. For PROG operation, XADR increases by 1 after NVSTR falls.
ZZ254 = 2
XADR increased for diagonal. For PROG-DIAGONAL operation, XADR is increased to create diagonal pattern.
ZZ255 = 3
XADR increased by sector. During ERASE operation, XADR increased by number of rows in a sector when NVSTR falls.
ZZ256 = 4
XADR inversed. XADR is inversed after reading one word or after programming one row when NVSTR falls.
ZZ257 = 5
XADR increased by 2 after row. For READ operation, XADR is increased by 2 after reading the last word of a row. For PROG operation, XADR is increased by 2 when NVSTR falls.
ZZ258 = 6
XADR[0] inversed. XADR[0] is inversed after reading one word or after programming one row when NVSTR falls.
ZZ259 = 7
XADR increased by 1. For READ operations only, XADR increased by 1 after each read cycle.
ZZ260 = 8
XADR decreased by 1 after row. For READ operations only, XADR is decreased by 1 after YADR decreases to 0.
ZZ261 = 9
XADR decreased by 1. For READ operations only, XADR is decreased by 1 after each read cycle.