#[repr(u8)]pub enum Fdfd {
ZZ41 = 0,
ZZ42 = 1,
}Variants
ZZ41 = 0
FSTAT[DFDIF] sets only if a double bit fault is detected during a valid flash read access from the FMC
ZZ42 = 1
FSTAT[DFDIF] sets during any valid flash read access from the FMC; an interrupt request is generated if the DFDIE bit is set
Implementations