#[repr(u8)]pub enum PdTimerEn {
ZZ127 = 0,
ZZ128 = 1,
}Variants
ZZ127 = 0
BIST timer is not triggered during Power Down recovery
ZZ128 = 1
BIST timer is triggered during Power Down recovery (default behavior)
Implementations