#[repr(u8)]pub enum RecallDataMismatch {
ZZ71 = 0,
ZZ72 = 1,
}Variants
ZZ71 = 0
Data read towards end of reset matched data read for Recall
ZZ72 = 1
Data read towards end of reset did not match data read for recall
Implementations