#[repr(u8)]pub enum Smwtst {
ZZ209 = 0,
ZZ210 = 1,
ZZ211 = 2,
_RESERVED_3 = 3,
}Variants
ZZ209 = 0
Default
ZZ210 = 1
Enable SMWR self-test mode, DOUT from macro will be forced to all 0
ZZ211 = 2
Enable SMWR self-test mode, DOUT from macro will be forced to all 1
_RESERVED_3 = 3
Implementations